@@ -6,4 +6,8 @@ PRONOUNS_ADJ = (u'PN_ADJ', u'МС-П',)
 VERBS = (u'Г', u'VERB',  u'ИНФИНИТИВ',)
 ADJECTIVE = (u'ADJECTIVE', u'П',)
 
-PRODUCTIVE_CLASSES = NOUNS + VERBS + ADJECTIVE + (u'Н',)
\ No newline at end of file
+PRODUCTIVE_CLASSES = NOUNS + VERBS + ADJECTIVE + (u'Н',)
+
+RU_CASES = (u'им', u'рд', u'дт', u'вн', u'тв', u'пр', u'зв',)
+RU_NUMBERS = (u'ед', u'мн')
+RU_GENDERS = (u'мр', u'жр', u'ср', u'мр-жр')
\ No newline at end of file
