@@ -3,6 +3,7 @@
 import os
 
 from pymorphy.constants import PRODUCTIVE_CLASSES, VERBS
+from pymorphy.constants import RU_CASES, RU_NUMBERS, RU_GENDERS
 from pymorphy.backends import PickleDataSource, ShelveDataSource
 
 from utils import mprint
@@ -24,6 +25,48 @@ def _array_match(arr, filter):
             return False
     return True
 
+
+class GramForm(object):
+    """ Класс для работы с грамматической формой """
+
+    def __init__(self, form_string):
+        self.form = self.parse_str(form_string)
+
+    def parse_str(self, form_string):
+        attrs = [a for a in form_string.split(',') if a]
+        return set(attrs)
+
+    def get_form_string(self):
+        return ",".join(self.form)
+
+    def clear_number(self):
+        ''' убрать информацию о числе '''
+        self.form.difference_update(RU_NUMBERS)
+
+    def clear_case(self):
+        ''' убрать информацию о падеже '''
+        self.form.difference_update(RU_CASES)
+
+    def clear_gender(self):
+        ''' убрать информацию о роде '''
+        self.form.difference_update(RU_GENDERS)
+
+    def update(self, form_string):
+        """ Обновляет параметры, по возможности оставляя все, что можно. """
+        requested_form = self.parse_str(form_string)
+        for item in requested_form:
+            if item in RU_NUMBERS:
+                self.clear_number()
+                if item==u'мн':
+                    self.clear_gender()
+            if item in RU_CASES:
+                self.clear_case()
+            if item in RU_GENDERS:
+                self.clear_gender()
+        self.form.update(requested_form)
+        return self
+
+
 class Morph:
     """ Класс, реализующий морфологический анализ на основе словарей из
         data_source
@@ -83,24 +126,34 @@ class Morph:
                 variants.append(form)
         return variants
 
-    def pluralize_ru(self, word, gram_form='', gram_class=None):
+    def inflect_ru(self, word, gram_form, gram_class=None):
         """
-        Вернуть слово во множественном числе.
+        Вернуть вариант слова, который соотвествует данной грамматической
+        форме и части речи, а также менее всего отличается от исходного.
         """
         forms = self.get_graminfo(word)
         if not forms:
             return word
         graminfo = forms[0]
-        form = graminfo['info'].replace(u'ед', u'мн')
-        if graminfo['class'] in VERBS:
-            form = form.replace(u"мр", '').replace(u"жр",'').replace(u'ср','')
-        variants = self.decline(word, form, graminfo['class'])
+
+        form = GramForm(graminfo['info'])
+        form.update(gram_form)
+
+        variants = self.decline(word, form.get_form_string(), graminfo['class'])
         if len(variants):
-            return variants[0]['norm']
+            return variants[0]['word']
         else:
             return word
 
 
+    def pluralize_ru(self, word, gram_form='', gram_class=None):
+        """
+        Вернуть слово во множественном числе.
+        """
+        form = GramForm(gram_form).update(u'мн')
+        return self.inflect_ru(word, form.get_form_string(), gram_class)
+
+
 #----------- internal methods -------------
 
     def _drop_cache(self):
@@ -110,10 +163,10 @@ class Morph:
         self.data.endings.cache = {}
 
 
-    def _decline(self, word):
+    def _decline(self, src_word):
         """ Просклонять: вернуть все грам. формы с информацией про них """
 
-        word_graminfo = self.get_graminfo(word)
+        word_graminfo = self.get_graminfo(src_word)
 
         forms = []
 
@@ -135,9 +188,9 @@ class Morph:
                 suffix, ancode, prefix = rule
                 cls, info, _letter  = self.data.gramtab[ancode]
 
-                norm = pre_prefix + prefix + lemma + suffix
+                word = pre_prefix + prefix + lemma + suffix
                 forms.append({
-                    'norm': norm,
+                    'word': word,
                     'class': cls,
                     'info': info,
                     'lemma': lemma,
